/**
 * Wikitude Studio API
 * The Wikitude Studio API is a RESTful API which is used to * organize and manipulate projects and its targets * create wtc/wto files which can be used to create trackers in the Wikitude SDK with the JavaScript API * generate/publish a cloud archive to the cloud recognition service (image targets only)  Download API clients: * [`OpenAPI 3.0`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-openapi.zip) * [`JavaScript`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-javascript.zip) * [`Python`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-python.zip) * [`PHP`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-php.zip) * [`TypeScript (NodeJS)`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-typescript-node.zip) * [`Java`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-java.zip) * [`Ruby`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-ruby.zip) * [`C# .NET Core`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-csharp-netcore.zip)  This technical reference formally explains various API endpoints. Visit the [`Studio API documentation`](https://www.wikitude.com/external/doc/documentation/studio/) for a more general description. 
 *
 * The version of the OpenAPI document: 3.0.0
 * 
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 *
 */


import ApiClient from "../ApiClient";
import CreateImageTargetsBody from '../model/CreateImageTargetsBody';
import CreateImageTargetsResponse from '../model/CreateImageTargetsResponse';
import ImageTargetResponse from '../model/ImageTargetResponse';
import UpdateImageTargetBody from '../model/UpdateImageTargetBody';

/**
* ImageTarget service.
* @module api/ImageTargetApi
* @version 3.0.0
*/
export default class ImageTargetApi {

    /**
    * Constructs a new ImageTargetApi. 
    * @alias module:api/ImageTargetApi
    * @class
    * @param {module:ApiClient} [apiClient] Optional API client implementation to use,
    * default to {@link module:ApiClient#instance} if unspecified.
    */
    constructor(apiClient) {
        this.apiClient = apiClient || ApiClient.instance;
    }



    /**
     * Create Image Targets
     * Create a set of up to 10 new Targets in a Target Collection in your account. The task to create the listed Targets is scheduled. The response body contains the initial job status. \"Location\"-header is the url to the GET endpoint that returns current job status information. It is recommended to query this endpoint after \"estimatedLatency\" milliseconds, and poll it afterwards every 10 seconds in case job status is still not \"COMPLETED\". Once job status is \"COMPLETED\" each item holds a \"target\" attribute of the created target or an \"error\" attribute. 
     * @param {String} xVersion The version of the API to be used. Must be set to 3.
     * @param {String} xToken Your Manager Token.
     * @param {String} contentType The Content Type of the body. Must be set to application/json.
     * @param {String} tcId Unique identifier of the Image Target Collection.
     * @param {Object} opts Optional parameters
     * @param {Array.<module:model/CreateImageTargetsBody>} opts.createImageTargetsBody 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/CreateImageTargetsResponse} and HTTP response
     */
    createImageTargetsWithHttpInfo(xVersion, xToken, contentType, tcId, opts) {
      opts = opts || {};
      let postBody = opts['createImageTargetsBody'];
      // verify the required parameter 'xVersion' is set
      if (xVersion === undefined || xVersion === null) {
        throw new Error("Missing the required parameter 'xVersion' when calling createImageTargets");
      }
      // verify the required parameter 'xToken' is set
      if (xToken === undefined || xToken === null) {
        throw new Error("Missing the required parameter 'xToken' when calling createImageTargets");
      }
      // verify the required parameter 'contentType' is set
      if (contentType === undefined || contentType === null) {
        throw new Error("Missing the required parameter 'contentType' when calling createImageTargets");
      }
      // verify the required parameter 'tcId' is set
      if (tcId === undefined || tcId === null) {
        throw new Error("Missing the required parameter 'tcId' when calling createImageTargets");
      }

      let pathParams = {
        'tcId': tcId
      };
      let queryParams = {
      };
      let headerParams = {
        'X-Version': xVersion,
        'X-Token': xToken,
        'Content-Type': contentType
      };
      let formParams = {
      };

      let authNames = [];
      let contentTypes = ['application/json'];
      let accepts = ['application/json'];
      let returnType = CreateImageTargetsResponse;
      return this.apiClient.callApi(
        '/targetCollection/{tcId}/targets', 'POST',
        pathParams, queryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType, null
      );
    }

    /**
     * Create Image Targets
     * Create a set of up to 10 new Targets in a Target Collection in your account. The task to create the listed Targets is scheduled. The response body contains the initial job status. \"Location\"-header is the url to the GET endpoint that returns current job status information. It is recommended to query this endpoint after \"estimatedLatency\" milliseconds, and poll it afterwards every 10 seconds in case job status is still not \"COMPLETED\". Once job status is \"COMPLETED\" each item holds a \"target\" attribute of the created target or an \"error\" attribute. 
     * @param {String} xVersion The version of the API to be used. Must be set to 3.
     * @param {String} xToken Your Manager Token.
     * @param {String} contentType The Content Type of the body. Must be set to application/json.
     * @param {String} tcId Unique identifier of the Image Target Collection.
     * @param {Object} opts Optional parameters
     * @param {Array.<module:model/CreateImageTargetsBody>} opts.createImageTargetsBody 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/CreateImageTargetsResponse}
     */
    createImageTargets(xVersion, xToken, contentType, tcId, opts) {
      return this.createImageTargetsWithHttpInfo(xVersion, xToken, contentType, tcId, opts)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }


    /**
     * Delete Image Target
     * Delete a particular Target from your account.
     * @param {String} xVersion The version of the API to be used. Must be set to 3.
     * @param {String} xToken Your Manager Token.
     * @param {String} tcId Unique identifier of the Image Target Collection.
     * @param {String} targetId Unique identifier of the Image Target.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing HTTP response
     */
    deleteImageTargetWithHttpInfo(xVersion, xToken, tcId, targetId) {
      let postBody = null;
      // verify the required parameter 'xVersion' is set
      if (xVersion === undefined || xVersion === null) {
        throw new Error("Missing the required parameter 'xVersion' when calling deleteImageTarget");
      }
      // verify the required parameter 'xToken' is set
      if (xToken === undefined || xToken === null) {
        throw new Error("Missing the required parameter 'xToken' when calling deleteImageTarget");
      }
      // verify the required parameter 'tcId' is set
      if (tcId === undefined || tcId === null) {
        throw new Error("Missing the required parameter 'tcId' when calling deleteImageTarget");
      }
      // verify the required parameter 'targetId' is set
      if (targetId === undefined || targetId === null) {
        throw new Error("Missing the required parameter 'targetId' when calling deleteImageTarget");
      }

      let pathParams = {
        'tcId': tcId,
        'targetId': targetId
      };
      let queryParams = {
      };
      let headerParams = {
        'X-Version': xVersion,
        'X-Token': xToken
      };
      let formParams = {
      };

      let authNames = [];
      let contentTypes = [];
      let accepts = [];
      let returnType = null;
      return this.apiClient.callApi(
        '/targetCollection/{tcId}/target/{targetId}', 'DELETE',
        pathParams, queryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType, null
      );
    }

    /**
     * Delete Image Target
     * Delete a particular Target from your account.
     * @param {String} xVersion The version of the API to be used. Must be set to 3.
     * @param {String} xToken Your Manager Token.
     * @param {String} tcId Unique identifier of the Image Target Collection.
     * @param {String} targetId Unique identifier of the Image Target.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}
     */
    deleteImageTarget(xVersion, xToken, tcId, targetId) {
      return this.deleteImageTargetWithHttpInfo(xVersion, xToken, tcId, targetId)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }


    /**
     * Get Image Target
     * Request a particular Image Target in a particular Target Collection.
     * @param {String} xVersion The version of the API to be used. Must be set to 3.
     * @param {String} xToken Your Manager Token.
     * @param {String} tcId Unique identifier of the Image Target Collection.
     * @param {String} targetId Unique identifier of the Image Target.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/ImageTargetResponse} and HTTP response
     */
    getImageTargetWithHttpInfo(xVersion, xToken, tcId, targetId) {
      let postBody = null;
      // verify the required parameter 'xVersion' is set
      if (xVersion === undefined || xVersion === null) {
        throw new Error("Missing the required parameter 'xVersion' when calling getImageTarget");
      }
      // verify the required parameter 'xToken' is set
      if (xToken === undefined || xToken === null) {
        throw new Error("Missing the required parameter 'xToken' when calling getImageTarget");
      }
      // verify the required parameter 'tcId' is set
      if (tcId === undefined || tcId === null) {
        throw new Error("Missing the required parameter 'tcId' when calling getImageTarget");
      }
      // verify the required parameter 'targetId' is set
      if (targetId === undefined || targetId === null) {
        throw new Error("Missing the required parameter 'targetId' when calling getImageTarget");
      }

      let pathParams = {
        'tcId': tcId,
        'targetId': targetId
      };
      let queryParams = {
      };
      let headerParams = {
        'X-Version': xVersion,
        'X-Token': xToken
      };
      let formParams = {
      };

      let authNames = [];
      let contentTypes = [];
      let accepts = ['application/json'];
      let returnType = ImageTargetResponse;
      return this.apiClient.callApi(
        '/targetCollection/{tcId}/target/{targetId}', 'GET',
        pathParams, queryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType, null
      );
    }

    /**
     * Get Image Target
     * Request a particular Image Target in a particular Target Collection.
     * @param {String} xVersion The version of the API to be used. Must be set to 3.
     * @param {String} xToken Your Manager Token.
     * @param {String} tcId Unique identifier of the Image Target Collection.
     * @param {String} targetId Unique identifier of the Image Target.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/ImageTargetResponse}
     */
    getImageTarget(xVersion, xToken, tcId, targetId) {
      return this.getImageTargetWithHttpInfo(xVersion, xToken, tcId, targetId)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }


    /**
     * Status - Image Targets Creation
     * Retrieves information status about a particular scheduled targets creation.
     * @param {String} xVersion The version of the API to be used. Must be set to 3.
     * @param {String} xToken Your Manager Token.
     * @param {String} tcId Unique identifier of the Image Target Collection.
     * @param {String} generationId Unique identifier of the asynchronous job created by a generation endpoint.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/CreateImageTargetsResponse} and HTTP response
     */
    getImageTargetStatusWithHttpInfo(xVersion, xToken, tcId, generationId) {
      let postBody = null;
      // verify the required parameter 'xVersion' is set
      if (xVersion === undefined || xVersion === null) {
        throw new Error("Missing the required parameter 'xVersion' when calling getImageTargetStatus");
      }
      // verify the required parameter 'xToken' is set
      if (xToken === undefined || xToken === null) {
        throw new Error("Missing the required parameter 'xToken' when calling getImageTargetStatus");
      }
      // verify the required parameter 'tcId' is set
      if (tcId === undefined || tcId === null) {
        throw new Error("Missing the required parameter 'tcId' when calling getImageTargetStatus");
      }
      // verify the required parameter 'generationId' is set
      if (generationId === undefined || generationId === null) {
        throw new Error("Missing the required parameter 'generationId' when calling getImageTargetStatus");
      }

      let pathParams = {
        'tcId': tcId,
        'generationId': generationId
      };
      let queryParams = {
      };
      let headerParams = {
        'X-Version': xVersion,
        'X-Token': xToken
      };
      let formParams = {
      };

      let authNames = [];
      let contentTypes = [];
      let accepts = ['application/json'];
      let returnType = CreateImageTargetsResponse;
      return this.apiClient.callApi(
        '/targetCollection/{tcId}/generation/targets/{generationId}', 'GET',
        pathParams, queryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType, null
      );
    }

    /**
     * Status - Image Targets Creation
     * Retrieves information status about a particular scheduled targets creation.
     * @param {String} xVersion The version of the API to be used. Must be set to 3.
     * @param {String} xToken Your Manager Token.
     * @param {String} tcId Unique identifier of the Image Target Collection.
     * @param {String} generationId Unique identifier of the asynchronous job created by a generation endpoint.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/CreateImageTargetsResponse}
     */
    getImageTargetStatus(xVersion, xToken, tcId, generationId) {
      return this.getImageTargetStatusWithHttpInfo(xVersion, xToken, tcId, generationId)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }


    /**
     * Get Image Targets
     * Request all Image Targets in a Target Collection.
     * @param {String} xVersion The version of the API to be used. Must be set to 3.
     * @param {String} xToken Your Manager Token.
     * @param {String} tcId Unique identifier of the Image Target Collection.
     * @param {Object} opts Optional parameters
     * @param {String} opts.sortby Targets may be sorted by 'name', 'creDat', 'modDat', 'rating'. Default value: 'creDat'
     * @param {String} opts.sortorder Targets may be sorted ascending ('asc') or descending ('desc'). Default value: 'desc'
     * @param {Number} opts.skip Set 0 to start with first target, set e.g. to 2 to skip first 2 targets. Default value: 0
     * @param {Number} opts.limit Set to 0 for 'all targets' or use positive value to define max. amount of targets to return. Default value: 0
     * @param {String} opts.s The search string to look for in target names.
     * @param {Boolean} opts.addHasAugmentations Add the hasAugmentations property.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link Array.<module:model/ImageTargetResponse>} and HTTP response
     */
    getImageTargetsWithHttpInfo(xVersion, xToken, tcId, opts) {
      opts = opts || {};
      let postBody = null;
      // verify the required parameter 'xVersion' is set
      if (xVersion === undefined || xVersion === null) {
        throw new Error("Missing the required parameter 'xVersion' when calling getImageTargets");
      }
      // verify the required parameter 'xToken' is set
      if (xToken === undefined || xToken === null) {
        throw new Error("Missing the required parameter 'xToken' when calling getImageTargets");
      }
      // verify the required parameter 'tcId' is set
      if (tcId === undefined || tcId === null) {
        throw new Error("Missing the required parameter 'tcId' when calling getImageTargets");
      }

      let pathParams = {
        'tcId': tcId
      };
      let queryParams = {
        'sortby': opts['sortby'],
        'sortorder': opts['sortorder'],
        'skip': opts['skip'],
        'limit': opts['limit'],
        's': opts['s'],
        'addHasAugmentations': opts['addHasAugmentations']
      };
      let headerParams = {
        'X-Version': xVersion,
        'X-Token': xToken
      };
      let formParams = {
      };

      let authNames = [];
      let contentTypes = [];
      let accepts = ['application/json'];
      let returnType = [ImageTargetResponse];
      return this.apiClient.callApi(
        '/targetCollection/{tcId}/target', 'GET',
        pathParams, queryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType, null
      );
    }

    /**
     * Get Image Targets
     * Request all Image Targets in a Target Collection.
     * @param {String} xVersion The version of the API to be used. Must be set to 3.
     * @param {String} xToken Your Manager Token.
     * @param {String} tcId Unique identifier of the Image Target Collection.
     * @param {Object} opts Optional parameters
     * @param {String} opts.sortby Targets may be sorted by 'name', 'creDat', 'modDat', 'rating'. Default value: 'creDat'
     * @param {String} opts.sortorder Targets may be sorted ascending ('asc') or descending ('desc'). Default value: 'desc'
     * @param {Number} opts.skip Set 0 to start with first target, set e.g. to 2 to skip first 2 targets. Default value: 0
     * @param {Number} opts.limit Set to 0 for 'all targets' or use positive value to define max. amount of targets to return. Default value: 0
     * @param {String} opts.s The search string to look for in target names.
     * @param {Boolean} opts.addHasAugmentations Add the hasAugmentations property.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link Array.<module:model/ImageTargetResponse>}
     */
    getImageTargets(xVersion, xToken, tcId, opts) {
      return this.getImageTargetsWithHttpInfo(xVersion, xToken, tcId, opts)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }


    /**
     * Update Image Target
     * Updates properties of a particular Target in your account. Currently following properties are supported: physicalHeight, metadata. 
     * @param {String} xVersion The version of the API to be used. Must be set to 3.
     * @param {String} xToken Your Manager Token.
     * @param {String} contentType The Content Type of the body. Must be set to application/json.
     * @param {String} tcId Unique identifier of the Image Target Collection.
     * @param {String} targetId Unique identifier of the Image Target.
     * @param {module:model/UpdateImageTargetBody} updateImageTargetBody 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/ImageTargetResponse} and HTTP response
     */
    updateImageTargetWithHttpInfo(xVersion, xToken, contentType, tcId, targetId, updateImageTargetBody) {
      let postBody = updateImageTargetBody;
      // verify the required parameter 'xVersion' is set
      if (xVersion === undefined || xVersion === null) {
        throw new Error("Missing the required parameter 'xVersion' when calling updateImageTarget");
      }
      // verify the required parameter 'xToken' is set
      if (xToken === undefined || xToken === null) {
        throw new Error("Missing the required parameter 'xToken' when calling updateImageTarget");
      }
      // verify the required parameter 'contentType' is set
      if (contentType === undefined || contentType === null) {
        throw new Error("Missing the required parameter 'contentType' when calling updateImageTarget");
      }
      // verify the required parameter 'tcId' is set
      if (tcId === undefined || tcId === null) {
        throw new Error("Missing the required parameter 'tcId' when calling updateImageTarget");
      }
      // verify the required parameter 'targetId' is set
      if (targetId === undefined || targetId === null) {
        throw new Error("Missing the required parameter 'targetId' when calling updateImageTarget");
      }
      // verify the required parameter 'updateImageTargetBody' is set
      if (updateImageTargetBody === undefined || updateImageTargetBody === null) {
        throw new Error("Missing the required parameter 'updateImageTargetBody' when calling updateImageTarget");
      }

      let pathParams = {
        'tcId': tcId,
        'targetId': targetId
      };
      let queryParams = {
      };
      let headerParams = {
        'X-Version': xVersion,
        'X-Token': xToken,
        'Content-Type': contentType
      };
      let formParams = {
      };

      let authNames = [];
      let contentTypes = ['application/json'];
      let accepts = ['application/json'];
      let returnType = ImageTargetResponse;
      return this.apiClient.callApi(
        '/targetCollection/{tcId}/target/{targetId}', 'POST',
        pathParams, queryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType, null
      );
    }

    /**
     * Update Image Target
     * Updates properties of a particular Target in your account. Currently following properties are supported: physicalHeight, metadata. 
     * @param {String} xVersion The version of the API to be used. Must be set to 3.
     * @param {String} xToken Your Manager Token.
     * @param {String} contentType The Content Type of the body. Must be set to application/json.
     * @param {String} tcId Unique identifier of the Image Target Collection.
     * @param {String} targetId Unique identifier of the Image Target.
     * @param {module:model/UpdateImageTargetBody} updateImageTargetBody 
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/ImageTargetResponse}
     */
    updateImageTarget(xVersion, xToken, contentType, tcId, targetId, updateImageTargetBody) {
      return this.updateImageTargetWithHttpInfo(xVersion, xToken, contentType, tcId, targetId, updateImageTargetBody)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }


}
